@@ -14,11 +14,26 @@
 } 
 
 get_caller_package <- function(caller) {
-    if (is.character) {
-        fn <- eval(parse(text=caller))
+    if (is.character(caller)) {
+        fn <- tryCatch(eval(parse(text=caller)), error=function(e) NULL)
+        if (is.null(fn)) return("")
     } else {
         fn <- caller
     }
 
     return(environmentName(environment(fn)))
 }
+
+.called_by_package <- function(package) {
+  call_stack <- sys.calls()
+  pattern <- sprintf("^package:%s", package)
+  for (call in call_stack) {
+    call <- as.character(as.expression(call))
+    if (grepl(pattern, call)) {
+      return(TRUE)
+    }
+  }
+  return(FALSE)
+}
+
+
